#' ---
#' title: Supplement to 'Estimating interactions between individuals from concurrent animal movements'
#' author: Ulrike E. Schlägel, Johannes Signer, Antje Herde, Sophie Eden, Florian Jeltsch, Jana A. Eccard, Melanie Dammhahn
#' date: Published in Methods in Ecology and Evolution (2019)
#' ---

#+ setup, include = FALSE
knitr::opts_chunk$set(cache = TRUE, message = FALSE, warning = FALSE)

#' ## Purpose
#' 
#' Test if an individual reacts to an other individual. 
#' 
#' ## Data and setup
#' 
#' We will need the following packages. 
library(raster)
library(tidyverse)
library(amt)

#' We start by loading a simulated example data set of two individuals that are attracted to each other.
dat <- read_rds("example_data.rds")

#' Next we create track, 
dat1 <- dat %>% make_track(x, y, date, id = id, crs = CRS("+init=epsg:4326"))

#' and can visually inspect the two individuals.
#' 

dat1 %>% ggplot(aes(x_, y_, col = id)) + geom_path()

#' ## Estimating the occurrence distribution (OD)
#' 
#' In order to estimate an OD, we will have to provide a template raster (i.e., the raster on which the OD is projected). We use the function `bbox` to create an extent of the template raster and give it a resolution of 1.
trast <- raster(amt::bbox(dat1, buffer = 20), res = 1)

#' We can inspect the raster. 
trast[] <- 1
plot(trast)

#' Subset the data such that data of only the first individual is retained (`r01.1`). 
#' We want to test if the second individual is attracted to or avoiding this first one.
dat2 <- filter(dat1, id == "r01.1")

#' First, we will estimate an overall OD. 
od1 <- od(dat2, trast)
raster::plot(od1)

#' Next, we want to estimate an OD for a rolling window of 40 time steps and create a raster stack. 

od_roll <- rolling_od(dat2, trast, n.points=40, show.progress = FALSE)

#' If you are rerunning the code try: `raster::animate(od_roll)` to get an animated version of the rolling OD. 
#' 
#' ## Fit a Step-Selection Function
#' 
#' We can now use the rolling OD as a predictor for the habitat selection of
#' the other individual (`r01.2`).

m1 <- dat1 %>% filter(id == "r01.2") %>% steps() %>% random_steps() %>%
  extract_covariates_var_time(od_roll, max_time = minutes(5), when = "before",
                              name_covar = "opponent") %>%
  filter(!is.na(opponent)) %>% fit_ssf(case_ ~ opponent + strata(step_id_))

summary(m1)

#' As expected, there is a significant positive selection for the opponent.
#' 
#' ## Session
#' 
sessionInfo()

     